@@ -23,6 +23,9 @@ ctfbe("<THE_PATH_TO_THE_FILE_TO_BE_DECRYPTED>").decode(passw="<PASSWORD>",key_pa
 ##################################################################
 # CHANGELOG :
 #s
+## 1.0.2
+ - Cancel the second level of encryption to increase speed.
+
 ## 1.0.1
  - Fix bugs.
 
@@ -32,7 +35,7 @@ ctfbe("<THE_PATH_TO_THE_FILE_TO_BE_DECRYPTED>").decode(passw="<PASSWORD>",key_pa
 ##################################################################
 """
 # VALUES :
-__version__="1.0.1"
+__version__="1.0.2"
 __name__="ctfbe"
 __author__="Yasser Bdj (Boudjada Yasser)"
 __author_email__="yasser.bdj96@gmail.com"
@@ -171,6 +174,9 @@ class ctfbe:
         level_1=file_final_str
         ctfbe.see(self.see,"[DONE]",False)
 
+        level_2=level_1
+
+        """
         #level_2:
         ctfbe.see(self.see,"    - Encryption level 2...")
         level_2=""
@@ -178,7 +184,8 @@ class ctfbe:
             char=list(level_1)
             level_2+=ctfbe.lower_upper(char[i])
         ctfbe.see(self.see,"[DONE]",False)
-
+        """
+        
         #level_3:
         ctfbe.see(self.see,"    - Encryption level 3...")
         level_3=level_2[::-1]
@@ -275,6 +282,9 @@ class ctfbe:
         level_3=level_3[::-1]
         ctfbe.see(self.see,"[DONE]",False)
         
+        level_2=level_3
+        
+        """
         #level_2:
         ctfbe.see(self.see,"    - Level 2 decoding...")
         level_2=""
@@ -282,6 +292,7 @@ class ctfbe:
             char=list(level_3)
             level_2+=ctfbe.lower_upper(char[i])
         ctfbe.see(self.see,"[DONE]",False)
+        """
         
         #level_1:
         ctfbe.see(self.see,"    - Level 1 decoding...")
